@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -36,7 +36,8 @@ class DomainClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("BatchModifyDomainInfo", params)
+            headers = request.headers
+            body = self.call("BatchModifyDomainInfo", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.BatchModifyDomainInfoResponse()
@@ -64,7 +65,8 @@ class DomainClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CheckBatchStatus", params)
+            headers = request.headers
+            body = self.call("CheckBatchStatus", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CheckBatchStatusResponse()
@@ -92,7 +94,8 @@ class DomainClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CheckDomain", params)
+            headers = request.headers
+            body = self.call("CheckDomain", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CheckDomainResponse()
@@ -120,7 +123,8 @@ class DomainClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateDomainBatch", params)
+            headers = request.headers
+            body = self.call("CreateDomainBatch", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateDomainBatchResponse()
@@ -138,6 +142,35 @@ class DomainClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def CreatePhoneEmail(self, request):
+        """此接口用于创建有效的手机、邮箱
+
+        :param request: Request instance for CreatePhoneEmail.
+        :type request: :class:`tencentcloud.domain.v20180808.models.CreatePhoneEmailRequest`
+        :rtype: :class:`tencentcloud.domain.v20180808.models.CreatePhoneEmailResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreatePhoneEmail", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.CreatePhoneEmailResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def CreateTemplate(self, request):
         """本接口 ( CreateTemplate ) 用于添加域名信息模板 。
 
@@ -148,7 +181,8 @@ class DomainClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateTemplate", params)
+            headers = request.headers
+            body = self.call("CreateTemplate", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateTemplateResponse()
@@ -166,6 +200,35 @@ class DomainClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DeletePhoneEmail(self, request):
+        """此接口用于删除已验证的手机邮箱
+
+        :param request: Request instance for DeletePhoneEmail.
+        :type request: :class:`tencentcloud.domain.v20180808.models.DeletePhoneEmailRequest`
+        :rtype: :class:`tencentcloud.domain.v20180808.models.DeletePhoneEmailResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DeletePhoneEmail", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DeletePhoneEmailResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DeleteTemplate(self, request):
         """本接口 ( DeleteTemplate ) 用于删除信息模板。
 
@@ -176,7 +239,8 @@ class DomainClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteTemplate", params)
+            headers = request.headers
+            body = self.call("DeleteTemplate", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteTemplateResponse()
@@ -204,7 +268,8 @@ class DomainClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeBatchOperationLogDetails", params)
+            headers = request.headers
+            body = self.call("DescribeBatchOperationLogDetails", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeBatchOperationLogDetailsResponse()
@@ -232,7 +297,8 @@ class DomainClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeBatchOperationLogs", params)
+            headers = request.headers
+            body = self.call("DescribeBatchOperationLogs", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeBatchOperationLogsResponse()
@@ -260,7 +326,8 @@ class DomainClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeDomainBaseInfo", params)
+            headers = request.headers
+            body = self.call("DescribeDomainBaseInfo", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeDomainBaseInfoResponse()
@@ -288,7 +355,8 @@ class DomainClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeDomainNameList", params)
+            headers = request.headers
+            body = self.call("DescribeDomainNameList", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeDomainNameListResponse()
@@ -316,7 +384,8 @@ class DomainClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeDomainPriceList", params)
+            headers = request.headers
+            body = self.call("DescribeDomainPriceList", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeDomainPriceListResponse()
@@ -334,6 +403,64 @@ class DomainClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeDomainSimpleInfo(self, request):
+        """获取域名实名信息详情
+
+        :param request: Request instance for DescribeDomainSimpleInfo.
+        :type request: :class:`tencentcloud.domain.v20180808.models.DescribeDomainSimpleInfoRequest`
+        :rtype: :class:`tencentcloud.domain.v20180808.models.DescribeDomainSimpleInfoResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeDomainSimpleInfo", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeDomainSimpleInfoResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def DescribePhoneEmailList(self, request):
+        """本接口用于获取已验证的手机邮箱列表
+
+        :param request: Request instance for DescribePhoneEmailList.
+        :type request: :class:`tencentcloud.domain.v20180808.models.DescribePhoneEmailListRequest`
+        :rtype: :class:`tencentcloud.domain.v20180808.models.DescribePhoneEmailListResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribePhoneEmailList", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribePhoneEmailListResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeTemplate(self, request):
         """本接口 (DescribeTemplate) 用于获取模板信息。
 
@@ -344,7 +471,8 @@ class DomainClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeTemplate", params)
+            headers = request.headers
+            body = self.call("DescribeTemplate", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeTemplateResponse()
@@ -372,7 +500,8 @@ class DomainClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeTemplateList", params)
+            headers = request.headers
+            body = self.call("DescribeTemplateList", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeTemplateListResponse()
@@ -400,7 +529,8 @@ class DomainClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyDomainDNSBatch", params)
+            headers = request.headers
+            body = self.call("ModifyDomainDNSBatch", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyDomainDNSBatchResponse()
@@ -428,7 +558,8 @@ class DomainClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyDomainOwnerBatch", params)
+            headers = request.headers
+            body = self.call("ModifyDomainOwnerBatch", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyDomainOwnerBatchResponse()
@@ -456,7 +587,8 @@ class DomainClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("RenewDomainBatch", params)
+            headers = request.headers
+            body = self.call("RenewDomainBatch", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.RenewDomainBatchResponse()
@@ -474,6 +606,35 @@ class DomainClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def SendPhoneEmailCode(self, request):
+        """此接口用于发送手机邮箱验证码。
+
+        :param request: Request instance for SendPhoneEmailCode.
+        :type request: :class:`tencentcloud.domain.v20180808.models.SendPhoneEmailCodeRequest`
+        :rtype: :class:`tencentcloud.domain.v20180808.models.SendPhoneEmailCodeResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("SendPhoneEmailCode", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.SendPhoneEmailCodeResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def SetDomainAutoRenew(self, request):
         """本接口 ( SetDomainAutoRenew ) 用于设置域名自动续费。
 
@@ -484,7 +645,8 @@ class DomainClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("SetDomainAutoRenew", params)
+            headers = request.headers
+            body = self.call("SetDomainAutoRenew", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.SetDomainAutoRenewResponse()
@@ -512,7 +674,8 @@ class DomainClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("TransferInDomainBatch", params)
+            headers = request.headers
+            body = self.call("TransferInDomainBatch", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.TransferInDomainBatchResponse()
@@ -540,7 +703,8 @@ class DomainClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("TransferProhibitionBatch", params)
+            headers = request.headers
+            body = self.call("TransferProhibitionBatch", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.TransferProhibitionBatchResponse()
@@ -568,7 +732,8 @@ class DomainClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("UpdateProhibitionBatch", params)
+            headers = request.headers
+            body = self.call("UpdateProhibitionBatch", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.UpdateProhibitionBatchResponse()
@@ -596,7 +761,8 @@ class DomainClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("UploadImage", params)
+            headers = request.headers
+            body = self.call("UploadImage", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.UploadImageResponse()
