@@ -91,3 +91,6 @@ UNKNOWNPARAMETER = 'UnknownParameter'
 
 # 操作不支持。
 UNSUPPORTEDOPERATION = 'UnsupportedOperation'
+
+# 语音转文本开关未开启。
+UNSUPPORTEDOPERATION_PTTSWITCHOFF = 'UnsupportedOperation.PTTSwitchOff'
