@@ -1899,7 +1899,7 @@ class MariadbClient(AbstractClient):
 
 
     def TerminateDedicatedDBInstance(self, request):
-        """本接口（IsolateDedicatedDBInstance）用于销毁已隔离的独享云数据库实例。
+        """本接口（TerminateDedicatedDBInstance）用于销毁已隔离的独享云数据库实例。
 
         :param request: Request instance for TerminateDedicatedDBInstance.
         :type request: :class:`tencentcloud.mariadb.v20170312.models.TerminateDedicatedDBInstanceRequest`
